@@ -1,23 +1,22 @@
 #!/usr/bin/env/ python
 """
-    AWS KEYSPACE CONNECTOR
+    LABUNIX AWS KEYSPACES CONNECTOR
 """
 from functools import wraps
 import os
 
 from cassandra import ConsistencyLevel
-from cassandra.policies import RoundRobinPolicy
-
 from cassandra.cqlengine import connection
 from cassandra.io.libevreactor import LibevConnection
+from cassandra.policies import ExponentialReconnectionPolicy
 
 from .auth import _auth_provider, _ssl_context
+from .config import CLUSTER_HOST, CLUSTER_PORT, CLUSTER_KSP
+from .profile import default
+
 
 __all__ = ["connection", "get_session"]
 
-_CLUSTER_HOST = os.getenv("CLUSTER_HOST", "127.0.0.1").split(",")
-_CLUSTER_PORT = int(os.getenv("CLUSTER_PORT", 9142))
-
 
 def connect(orig_function):
     """
@@ -30,15 +29,24 @@ def connect(orig_function):
     @wraps(orig_function)
     def wrapper(*args, **kwargs):
         connection.setup(
-            hosts=_CLUSTER_HOST,
+            hosts=CLUSTER_HOST,
             ssl_context=_ssl_context,
             auth_provider=_auth_provider,
-            port=_CLUSTER_PORT,
-            load_balancing_policy=RoundRobinPolicy(),
-            default_keyspace=os.getenv("CLUSTER_KSP"),
+            port=CLUSTER_PORT,
+            idle_heartbeat_interval=5,
+            idle_heartbeat_timeout=10,
+            reconnection_policy=ExponentialReconnectionPolicy(
+                1.0, 
+                900.0, 
+                max_attempts=None
+            ),
+            default_keyspace=CLUSTER_KSP,
             protocol_version=4,
             lazy_connect=False,
             retry_connect=True,
+            control_connection_timeout=30,
+            connect_timeout=30,
+            execution_profiles=default,
             consistency=ConsistencyLevel.LOCAL_QUORUM,
             connection_class=LibevConnection,
         )
